@@ -22,7 +22,12 @@ def image_resizing(origin: Image, target_size: int, file: str):
         if size <= target_size:
             if target_size - size < target_size * 0.01:
                 basename = filepath2basename_without_extension(file)
-                resized.save(f"{basename}_resized.{origin.format.lower()}")
+                resized.save(
+                    f"{basename}_resized.{origin.format.lower()}",
+                    format=origin.format,
+                    quality=95,
+                    subsampling=0,
+                )
                 break
             l = mid + 1
         else:
